# coding: utf-8

"""
    

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class HnswIterativeScan(str, Enum):
    """
    HnswIterativeScan
    """

    """
    allowed enum values
    """
    ITERATIVE_SCAN_UNSPECIFIED = 'ITERATIVE_SCAN_UNSPECIFIED'
    ITERATIVE_SCAN_OFF = 'ITERATIVE_SCAN_OFF'
    ITERATIVE_SCAN_RELAXED_ORDER = 'ITERATIVE_SCAN_RELAXED_ORDER'
    ITERATIVE_SCAN_STRICT_ORDER = 'ITERATIVE_SCAN_STRICT_ORDER'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of HnswIterativeScan from a JSON string"""
        return cls(json.loads(json_str))


