# coding: utf-8

"""
    

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class OcrInputFormat(str, Enum):
    """
    OcrInputFormat
    """

    """
    allowed enum values
    """
    AUTO = 'AUTO'
    PDF = 'PDF'
    TIFF = 'TIFF'
    PNG = 'PNG'
    JPEG = 'JPEG'
    BMP = 'BMP'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of OcrInputFormat from a JSON string"""
        return cls(json.loads(json_str))


