# coding: utf-8

"""
    

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from goodmem._generated.models.ping_endpoint_info import PingEndpointInfo
from typing import Optional, Set
from typing_extensions import Self

class PingSummary(BaseModel):
    """
    Summary emitted at the end of a ping session
    """ # noqa: E501
    endpoint: PingEndpointInfo
    requests: StrictInt = Field(description="Total number of probes scheduled")
    responses: StrictInt = Field(description="Number of responses received (including timeouts/errors)")
    ok: StrictInt = Field(description="Count of probes that succeeded")
    timeouts: StrictInt = Field(description="Count of probes that exceeded the timeout")
    errors: StrictInt = Field(description="Count of probes that failed for other reasons")
    rtt_min_ms: Union[StrictFloat, StrictInt] = Field(description="Minimum observed round-trip latency (ms)", alias="rttMinMs")
    rtt_avg_ms: Union[StrictFloat, StrictInt] = Field(description="Average observed round-trip latency (ms)", alias="rttAvgMs")
    rtt_p50_ms: Union[StrictFloat, StrictInt] = Field(description="Median (p50) round-trip latency (ms)", alias="rttP50Ms")
    rtt_p90_ms: Union[StrictFloat, StrictInt] = Field(description="90th percentile round-trip latency (ms)", alias="rttP90Ms")
    rtt_p99_ms: Union[StrictFloat, StrictInt] = Field(description="99th percentile round-trip latency (ms)", alias="rttP99Ms")
    rtt_max_ms: Union[StrictFloat, StrictInt] = Field(description="Maximum observed round-trip latency (ms)", alias="rttMaxMs")
    requests_per_second: Union[StrictFloat, StrictInt] = Field(description="Effective request throughput across the session", alias="requestsPerSecond")
    bytes_per_second: Union[StrictFloat, StrictInt] = Field(description="Aggregate bytes per second (send + receive)", alias="bytesPerSecond")
    applied_limits: Optional[Dict[str, StrictStr]] = Field(default=None, description="Resource limits applied by the server", alias="appliedLimits")
    __properties: ClassVar[List[str]] = ["endpoint", "requests", "responses", "ok", "timeouts", "errors", "rttMinMs", "rttAvgMs", "rttP50Ms", "rttP90Ms", "rttP99Ms", "rttMaxMs", "requestsPerSecond", "bytesPerSecond", "appliedLimits"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PingSummary from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of endpoint
        if self.endpoint:
            _dict['endpoint'] = self.endpoint.to_dict()
        # set to None if applied_limits (nullable) is None
        # and model_fields_set contains the field
        if self.applied_limits is None and "applied_limits" in self.model_fields_set:
            _dict['appliedLimits'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PingSummary from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "endpoint": PingEndpointInfo.from_dict(obj["endpoint"]) if obj.get("endpoint") is not None else None,
            "requests": obj.get("requests"),
            "responses": obj.get("responses"),
            "ok": obj.get("ok"),
            "timeouts": obj.get("timeouts"),
            "errors": obj.get("errors"),
            "rttMinMs": obj.get("rttMinMs"),
            "rttAvgMs": obj.get("rttAvgMs"),
            "rttP50Ms": obj.get("rttP50Ms"),
            "rttP90Ms": obj.get("rttP90Ms"),
            "rttP99Ms": obj.get("rttP99Ms"),
            "rttMaxMs": obj.get("rttMaxMs"),
            "requestsPerSecond": obj.get("requestsPerSecond"),
            "bytesPerSecond": obj.get("bytesPerSecond"),
            "appliedLimits": obj.get("appliedLimits")
        })
        return _obj


