# coding: utf-8

"""
    

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class OcrCategory(str, Enum):
    """
    OcrCategory
    """

    """
    allowed enum values
    """
    UNSPECIFIED = 'UNSPECIFIED'
    CAPTION = 'CAPTION'
    FOOTNOTE = 'FOOTNOTE'
    FORMULA = 'FORMULA'
    LIST_ITEM = 'LIST_ITEM'
    PAGE_FOOTER = 'PAGE_FOOTER'
    PAGE_HEADER = 'PAGE_HEADER'
    PICTURE = 'PICTURE'
    SECTION_HEADER = 'SECTION_HEADER'
    TABLE = 'TABLE'
    TEXT = 'TEXT'
    TITLE = 'TITLE'
    OTHER = 'OTHER'
    UNKNOWN = 'UNKNOWN'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of OcrCategory from a JSON string"""
        return cls(json.loads(json_str))


