# coding: utf-8

"""
    

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from goodmem._generated.models.ping_payload_type import PingPayloadType
from goodmem._generated.models.ping_target_type import PingTargetType
from typing import Optional, Set
from typing_extensions import Self

class PingOnceRequest(BaseModel):
    """
    Request payload for a single ping probe
    """ # noqa: E501
    target_id: StrictStr = Field(description="Target resource ID (UUID)", alias="targetId")
    target_type_hint: Optional[PingTargetType] = Field(default=None, alias="targetTypeHint")
    payload_type: Optional[PingPayloadType] = Field(default=None, alias="payloadType")
    payload: Optional[StrictStr] = Field(default=None, description="Explicit UTF-8 payload to send with the probe (mutually exclusive with payloadSizeBytes)")
    payload_size_bytes: Optional[StrictInt] = Field(default=None, description="Synthetic payload size in bytes (mutually exclusive with payload)", alias="payloadSizeBytes")
    timeout_ms: Optional[StrictInt] = Field(default=None, description="Per-probe timeout in milliseconds (0 uses server default)", alias="timeoutMs")
    __properties: ClassVar[List[str]] = ["targetId", "targetTypeHint", "payloadType", "payload", "payloadSizeBytes", "timeoutMs"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PingOnceRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if payload (nullable) is None
        # and model_fields_set contains the field
        if self.payload is None and "payload" in self.model_fields_set:
            _dict['payload'] = None

        # set to None if payload_size_bytes (nullable) is None
        # and model_fields_set contains the field
        if self.payload_size_bytes is None and "payload_size_bytes" in self.model_fields_set:
            _dict['payloadSizeBytes'] = None

        # set to None if timeout_ms (nullable) is None
        # and model_fields_set contains the field
        if self.timeout_ms is None and "timeout_ms" in self.model_fields_set:
            _dict['timeoutMs'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PingOnceRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "targetId": obj.get("targetId"),
            "targetTypeHint": obj.get("targetTypeHint"),
            "payloadType": obj.get("payloadType"),
            "payload": obj.get("payload"),
            "payloadSizeBytes": obj.get("payloadSizeBytes"),
            "timeoutMs": obj.get("timeoutMs")
        })
        return _obj


