# coding: utf-8

"""
    

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from goodmem._generated.models.secret_reference import SecretReference
from typing import Optional, Set
from typing_extensions import Self

class ApiKeyAuth(BaseModel):
    """
    Configuration for classic API-key authentication.
    """ # noqa: E501
    inline_secret: Optional[StrictStr] = Field(default=None, description="Secret stored directly in GoodMem (mutually exclusive with secretRef)", alias="inlineSecret")
    secret_ref: Optional[SecretReference] = Field(default=None, alias="secretRef")
    header_name: Optional[StrictStr] = Field(default=None, description="Desired HTTP header to carry the credential (defaults to Authorization)", alias="headerName")
    prefix: Optional[StrictStr] = Field(default=None, description="Optional prefix prepended to the secret (e.g., \"Bearer \")")
    __properties: ClassVar[List[str]] = ["inlineSecret", "secretRef", "headerName", "prefix"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiKeyAuth from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of secret_ref
        if self.secret_ref:
            _dict['secretRef'] = self.secret_ref.to_dict()
        # set to None if inline_secret (nullable) is None
        # and model_fields_set contains the field
        if self.inline_secret is None and "inline_secret" in self.model_fields_set:
            _dict['inlineSecret'] = None

        # set to None if header_name (nullable) is None
        # and model_fields_set contains the field
        if self.header_name is None and "header_name" in self.model_fields_set:
            _dict['headerName'] = None

        # set to None if prefix (nullable) is None
        # and model_fields_set contains the field
        if self.prefix is None and "prefix" in self.model_fields_set:
            _dict['prefix'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiKeyAuth from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "inlineSecret": obj.get("inlineSecret"),
            "secretRef": SecretReference.from_dict(obj["secretRef"]) if obj.get("secretRef") is not None else None,
            "headerName": obj.get("headerName"),
            "prefix": obj.get("prefix")
        })
        return _obj


